@@ -10,7 +10,7 @@ from typing import *
 
 __all__ = [
         # 'getPPrintStr',  'check', 'get_func_details', 'print_signature'
-        'PRINT', 'Print', 'print_exception',
+        'PRINT', 'Print', 'print_exception', 'PrettyPrint',
         # 'TITLE_TAG', 'DEFAULT_TAG', 'END_TAG',
         'Printer', 'pp', 'CallStack',
         'GetFunctionName', 'GetFuncModule',
@@ -85,11 +85,11 @@ class Printer(object):
         self._end = end
         self._use_double_quotes = use_double_quotes
         self._pp = _pp or NoStringWrappingPrettyPrinter.Create()
-        self.pprint = self._pp.pprint
 
     @property
-    def debug(self) -> bool: return __debug__
-    def check(self) -> bool: return not self.debug
+    def DEBUG(self) -> bool: return __debug__
+    @property
+    def can_print(self) -> bool: return not self.DEBUG
 
     def __enter__(self):
         self._active = True
@@ -101,14 +101,51 @@ class Printer(object):
 
 
     def Print(self, *args):
-        if self.check(): return
+        if self.can_print: return
         if self._active:
             return self.print(*args)
 
         with self as p:
             return p.print(*args)
 
-    def print(self, *args): return print(*args, sep='\n', end=self._end, file=self._file)
+    def print(self, *args):
+        if self._active:
+            return print(*args, sep='\n', end=self._end, file=self._file)
+
+        with self:
+            return print(*args, sep='\n', end=self._end, file=self._file)
+
+    @overload
+    def PrettyPrint(self, *args): ...
+    @overload
+    def PrettyPrint(self, title: str, *args): ...
+    @overload
+    def PrettyPrint(self, **kwargs): ...
+    @overload
+    def PrettyPrint(self, title: str, **kwargs): ...
+
+    def PrettyPrint(self, *args, **kwargs):
+        if kwargs:
+            with self as p:
+                if args and isinstance(args[0], str):
+                    title = args[0]
+                    p.Print(title)
+                    p._pp.pprint(kwargs)
+
+                else: p._pp.pprint(kwargs)
+
+        elif args:
+            with self as p:
+                if isinstance(args[0], str):
+                    title = args[0]
+                    args = args[1:]
+                    p.Print(title)
+                    p._pp.pprint(args)
+
+                else: p._pp.pprint(args)
+
+
+
 
     def getPPrintStr(self, o: any) -> str:
         """
@@ -123,7 +160,7 @@ class Printer(object):
 
 
     def print_exception(self, e: Exception):
-        if self.check(): return
+        if self.can_print: return
 
         with self._lock:
             traceback.print_exception(type(e), e, e.__traceback__)
@@ -151,7 +188,7 @@ class Printer(object):
         return result, tag, name, signature, pp_result
 
     def print_signature(self, func: callable, tag: str, *args, **kwargs):
-        if not self.debug: return
+        if not self.DEBUG: return
         assert ('{0}' in tag)
 
         result = func(*args, **kwargs)
@@ -195,13 +232,29 @@ def PRINT(title: str, *args, tag: str = pp.TITLE_TAG, **kwargs):
     """
     with pp as p:
         p.Print(tag.format(title))
-        return p.pprint(dict(args=args, kwargs=kwargs))
+        return p.PrettyPrint(dict(args=args, kwargs=kwargs))
 
 
 
 def Print(*args):
-    with pp:
-        return pp.Print(*args)
+    with pp as p:
+        return p.Print(*args)
 
 
-def print_exception(e: Exception): return pp.print_exception(e)
+def print_exception(e: Exception):
+    with pp as p:
+        return p.print_exception(e)
+
+
+
+@overload
+def PrettyPrint(*args): ...
+@overload
+def PrettyPrint(title: str, *args): ...
+@overload
+def PrettyPrint(**kwargs): ...
+@overload
+def PrettyPrint(title: str, **kwargs): ...
+
+
+def PrettyPrint(*args, **kwargs): return pp.PrettyPrint(*args, **kwargs)
